@@ -61,8 +61,8 @@ class SlurmEngine(Engine):
 
     def _submit(self, execution):
         url = os.path.join(
-            execution.storage["url"],
-            execution.storage.get("directory", ""),
+            execution.storage.config["url"],
+            execution.storage.config.get("directory", ""),
             execution.experiment_id,
         )
 
@@ -78,7 +78,7 @@ class SlurmEngine(Engine):
         import machinable as ml
         e = ml.Execution.from_storage('{url}')
         e.set_engine('native')
-        e.set_storage({execution.storage})
+        e.set_storage({execution.storage.config})
         e.set_project(ml.Project.from_json('{project}'))
         e.filter(lambda i, component, _: component == '$COMPONENT_ID')
         e.submit()
@@ -103,6 +103,7 @@ class SlurmEngine(Engine):
         ) in execution.schedule.iterate(execution.storage.config):
             component_id = component["flags"]["COMPONENT_ID"]
             script = f"{self.script}\n"
+            script += f"export MACHINABLE_PROJECT={execution.project.directory_path}\n"
             script += f"#SBATCH --job-name={execution.experiment_id}:{component_id}\n"
             script += f"#SBATCH -o {os.path.join(script_url.replace('osfs://', ''), component_id + '.out')}\n"
             try:
@@ -117,10 +118,6 @@ class SlurmEngine(Engine):
             except KeyError:
                 pass
 
-            script = script.replace(
-                "%PROJECT_DIRECTORY%", execution.project.directory_path
-            )
-
             # write script to disk
             target = os.path.join(
                 script_url.replace("osfs://", ""), f"{component_id}.sh"
