@@ -19,7 +19,7 @@ from ..project import Project
 from ..project.export import Export
 from ..registration import Registration
 from ..storage import Storage
-from ..storage.models.filesystem import StorageFileSystemModel
+from ..storage.experiment import StorageExperiment
 from ..utils.dicts import update_dict
 from ..utils.formatting import exception_to_str, msg
 from ..utils.host import get_host_info
@@ -83,6 +83,9 @@ class Execution(Jsonable):
         self.set_index(index)
         self.set_seed(seed)
 
+        self._behavior = {"raise_exceptions": False}
+        self.failures = 0
+
     def __call__(self, experiment, storage=None, engine=None, project=None, seed=None):
         self.set_storage(storage)
         self.set_experiment(experiment)
@@ -125,22 +128,26 @@ class Execution(Jsonable):
     def set_experiment(self, experiment):
         self.experiment = Experiment.create(experiment)
 
-        # compute experiment directory
+        # experiment directory
         experiment_directory = self.experiment.specification.get("directory", None)
         if experiment_directory is None:
             experiment_directory = get_settings()["default_directory"]
         if isinstance(experiment_directory, str):
             # replace magic variables
-            project_name = self.project.name if self.project else ""
-            experiment_directory = experiment_directory.replace(
-                "&PROJECT", project_name
-            )
-            module_name = (
-                self.experiment._resolved_module_origin
-                if hasattr(self.experiment, "_resolved_module_origin")
-                else ""
-            )
-            experiment_directory = experiment_directory.replace("&MODULE", module_name)
+            if experiment_directory.find("&PROJECT") != -1:
+                project_name = self.project.name if self.project else ""
+                experiment_directory = experiment_directory.replace(
+                    "&PROJECT", project_name.replace(".", "/")
+                )
+            if experiment_directory.find("&MODULE") != -1:
+                module_name = (
+                    self.experiment._resolved_module_origin
+                    if hasattr(self.experiment, "_resolved_module_origin")
+                    else ""
+                )
+                experiment_directory = experiment_directory.replace(
+                    "&MODULE", module_name
+                )
             try:
                 experiment_directory = dt.now().strftime(experiment_directory)
             except ValueError:
@@ -259,6 +266,12 @@ class Execution(Jsonable):
 
         return self
 
+    def set_behavior(self, **settings):
+        unknown_options = set(settings.keys()) - {"raise_exceptions"}
+        if len(unknown_options) > 0:
+            raise ValueError(f"Invalid options: {unknown_options}")
+        self._behavior.update(settings)
+
     def is_submitted(self):
         try:
             with open_fs(self.storage.config["url"]) as filesystem:
@@ -273,23 +286,24 @@ class Execution(Jsonable):
         if Registration.get().on_before_submit(self) is False:
             return False
 
+        self.failures = 0
         self.storage.config["experiment"] = self.experiment_id
 
         # check if URL is an existing experiment
         derived_from = None
         try:
-            target = StorageFileSystemModel(self.storage.config["url"])
-            if target.is_valid():
+            with open_fs(self.storage.config["url"]) as filesystem:
+                experiment_id = filesystem.load_file("execution.json")["experiment_id"]
                 # register URL as parent storage and rewrite to experiments/ subdirectory
                 self.storage.config["ancestor"] = {
                     "url": self.storage.config["url"],
-                    "experiment": target.experiment_id,
+                    "experiment": experiment_id,
                 }
                 self.storage.config["url"] = os.path.join(
                     self.storage.config["url"], "experiments"
                 )
                 derived_from = self.storage.config["ancestor"]["url"]
-        except (ValueError, KeyError):
+        except (ValueError, KeyError, FileNotFoundError):
             pass
 
         is_submitted = self.is_submitted()
@@ -315,18 +329,20 @@ class Execution(Jsonable):
                 code_backup = True
 
             # collect and write execution data
+            url = os.path.join(
+                storage.get("url", "mem://"),
+                storage.get("directory", ""),
+                storage["experiment"],
+            )
             data = {
-                "url": os.path.join(
-                    storage.get("url", "mem://"),
-                    storage.get("directory", ""),
-                    storage["experiment"],
-                ),
                 "code.json": {
                     "resolvers": {
                         "experiment": getattr(
                             self.experiment, "_resolved_by_expression", None
                         ),
-                        "storage": None,
+                        "storage": getattr(
+                            self.storage, "_resolved_by_expression", None
+                        ),
                         "engine": getattr(self.engine, "_resolved_by_expression", None),
                     },
                     "code_backup": code_backup,
@@ -338,16 +354,14 @@ class Execution(Jsonable):
                 "host.json": get_host_info(),
             }
 
-            with open_fs({"url": data["url"], "create": True}) as filesystem:
+            with open_fs({"url": url, "create": True}) as filesystem:
                 if code_backup:
                     self.project.backup_source_code(opener=filesystem.open)
 
                 for k, v in data.items():
-                    if k.find(".") == -1:
-                        continue
                     filesystem.save_file(name=k, data=v)
 
-            self.index.add(data)
+            self.index.add(StorageExperiment(url, data))
 
         Registration.get().on_submit(self, is_submitted)
 
@@ -357,6 +371,9 @@ class Execution(Jsonable):
         if index is None:
             index = len(self.schedule) - 1
         if isinstance(result, ExecutionException):
+            self.failures += 1
+            if self._behavior["raise_exceptions"]:
+                raise result
             self.engine.log(
                 f"Submission {self.components[index]} of experiment {self.experiment_id} failed "
                 f"({index + 1}/{len(self.schedule)}). "
@@ -488,7 +505,7 @@ class Execution(Jsonable):
 
     def serialize(self):
         return {
-            "id": self.experiment_id,
+            "experiment_id": self.experiment_id,
             "seed": self.seed,
             "timestamp": self.timestamp,
             "started_at": self.started_at,
@@ -505,6 +522,10 @@ class Execution(Jsonable):
         execution.started_at = serialized["started_at"]
         return execution
 
+    @property
+    def unique_id(self):
+        return self.experiment_id + "_" + self.components[0]
+
     @property
     def experiment_id(self):
         return encode_experiment_id(self.seed)
@@ -520,6 +541,7 @@ class Execution(Jsonable):
             f"Storage: {self.storage}", color="blue",
         )
         msg(f"Engine: {repr(self.engine)}", color="blue")
+        msg(f"Index: {repr(self.index)}", color="blue")
         msg(f"Project: {repr(self.project)}", color="blue")
 
         for (
