@@ -3,6 +3,7 @@ import os
 
 from ..utils.dicts import update_dict
 from ..utils.importing import resolve_instance
+from .experiment import StorageExperiment
 
 _latest = [None]
 
@@ -57,13 +58,16 @@ class Storage:
         if isinstance(args, dict):
             args = copy.deepcopy(args)
 
-        return Storage(args)
+        return cls(args)
 
     def get_url(self):
         return os.path.join(
             self.config["url"], self.config["directory"], self.config["experiment"]
         )
 
+    def get_experiment(self):
+        return StorageExperiment(self.get_url())
+
     def __str__(self):
         return self.__repr__()
 
